Connection

Struct Connection 

pub struct Connection { /* private fields */ }
Connection represents a currently connected WebSocket RPC channel. This struct owns a Messenger that has Messenger::notify function that can be used to post notifications to the connection. Messenger::close function can be used to terminate the connection asynchronously.

Implementations

Source

impl Connection

pub fn new( id: u64, peer: &SocketAddr, messenger: Arc<Messenger>, grpc_client: Option<Arc<GrpcClient>>, ) -> Connection

pub fn id(&self) -> u64

Obtain the connection id

pub fn messenger(&self) -> &Arc<Messenger>

Get a reference to the connection Messenger

pub fn grpc_client(&self) -> Arc<GrpcClient>

pub fn grpc_client_notify_target(&self) -> GrpcClientNotify

pub fn listener_id(&self) -> Option<ListenerId>

pub fn register_notification_listener(&self, listener_id: ListenerId)

pub fn peer(&self) -> &SocketAddr

pub fn create_serialized_notification_message<Ops, Msg>( encoding: Encoding, op: Ops, msg: Msg, ) -> WrpcResult<Message>
where Ops: OpsT, Msg: MsgT,

Creates a WebSocket Message that can be posted to the connection (Messenger) sink directly.