pub struct Router {
pub interface: Arc<Interface<Server, Connection, RpcApiOps>>,
pub server_context: Server,
}Expand description
A wrapper that creates an Interface instance and initializes
RPC methods and notifications against this interface. The interface
is later given to the RpcServer. This wrapper exists to allow
a single initialization location for both the Kaspad Server and
the GRPC Proxy.
Fields
interface: Arc<Interface<Server, Connection, RpcApiOps>>server_context: ServerImplementations