WebSocketCounters

Struct WebSocketCounters 

pub struct WebSocketCounters {
    pub total_connections: Arc<AtomicUsize>,
    pub active_connections: Arc<AtomicUsize>,
    pub handshake_failures: Arc<AtomicUsize>,
    pub rx_bytes: Arc<AtomicUsize>,
    pub tx_bytes: Arc<AtomicUsize>,
}
Atomic counters that allow tracking connection counts and cumulative message sizes in bytes (bandwidth consumption without accounting for the websocket framing overhead). These counters can be created and supplied externally or supplied as None.

Fields

total_connections: Arc<AtomicUsize>active_connections: Arc<AtomicUsize>handshake_failures: Arc<AtomicUsize>rx_bytes: Arc<AtomicUsize>tx_bytes: Arc<AtomicUsize>